@@ -1,8 +1,14 @@
+"""
+这是Fishconsole Project的功能模块，所有的比较强大的功能都会放在这里
+
+----
+
+"""
+
 from Fishconsole import fcv
 from Fishconsole import logs
 from Fishconsole import helps
 
-
 logs.系统日志("用户调用了Fishsys模块")
 # 导入强制更新系统所需要的内容
 PI = fcv.f_debug()
@@ -15,11 +21,25 @@ filecheck = fcv.f_debug()
 filecheck = filecheck["filecheck"]
 
 
-def 强制类型检测(任意变量,预期类型):
-    type值=str(type(任意变量))
-    变量类型=type值.split("'")[1]
+def 强制类型检测(任意变量, 预期类型):
+    """
+
+    Fishconsole Fishsys 强制类型检测
+
+    ----
+
+    - 就是检测目标变量的类型和指定的类型是不是一样的，如果是一样的，就返回ture，如果不是，就返回False
+
+    - 目标类型可根据所加的其他模块自动适应
+
+    :param 任意变量: 你需要比对的变量
+    :param 预期类型: 你需要验证的类型比如a=1，强制类型检测（a,'int'）
+    :return: bool
+    """
+    type值 = str(type(任意变量))
+    变量类型 = type值.split("'")[1]
     logs.系统日志(f"强制类型检测》展示提取出的变量类型》{变量类型}")
-    if 变量类型==预期类型:
+    if 变量类型 == 预期类型:
         logs.系统日志(f"强制类型检测》目标判断为真")
         return True
     else:
@@ -27,12 +47,18 @@ def 强制类型检测(任意变量,预期类型):
         return False
 
 
-
-
-
 # 这是一座屎山，能修则修，不能修就算了
 # 模式,加密密码,内容
 def passwordsys(模式: any, id_protect: str, password_a: str):
+    """
+
+    Fishconsole Fishsys passwordsys模块
+
+    ----
+
+    Fishconsole文本加解密核心模块，当然有现成的密码模块，那个很完善，可以加密中文，虽然它也要调用这个，毕竟是Fishconsole Project独家加密方式
+
+    """
     import re
     import base64
     password = str(password_a)
@@ -491,11 +517,25 @@ def passwordsys(模式: any, id_protect: str, password_a: str):
             logs.系统日志("密码验证成功", PI)
             return f"{text}"
         else:
-            logs.安全退出(logs.日志("您的密码是错误的，请核对后重新输入"), 色选="红色")
-
+            logs.安全退出(logs.日志("您的密码是错误的，请核对后重新输入"))
 
 
 def 密码(模式, 原文, 密码: str = ""):
+    """
+
+    Fishconsole Fishsys密码模块
+
+    ----
+
+    - 这个就是文字加解密模块了
+
+    - 它能将几乎可以加密所有的文字（其实就是转了个二进制哈哈），嗯，就这样
+
+    :param 模式: 选择加密（1）还是解密（2）
+    :param 原文: 原来的文字
+    :param 密码:  你说是啥子麻
+    :return:    操作后的文本
+    """
     if 模式 == 1:
         a = 字符转unicode(1, 原文)
         logs.系统日志(f"a is {a}", PI)
@@ -516,55 +556,88 @@ def 密码(模式, 原文, 密码: str = ""):
 
 
 def 网易云音乐(歌单链接: list):
-    import requests
-    from lxml import html
-    etree = html.etree
+    """
 
-    urllist = 歌单链接
-    base_url = 'https://link.hhtjim.com/163/'
-    count = 0
-    for url in urllist:
-        count = count + 1
-        print(logs.颜色(logs.分割线(f"开始第{count}次爬取", "Spider"), 色选="红色"))
-        result = requests.get(url).text
-        dom = etree.HTML(result)
-        # //a[@contains内容(@href指定查找的内容,'song?'含有的)]/@href里面的链接文字
-        ids = dom.xpath('//a[contains(@href,"song?")]/@href')
-        names = dom.xpath('//a[contains(@href,"song?")]/text()')
-        print(ids)
-        a = -1
-        for name in names:
-            a = a + 1
-            if not ('$' in name):
-                if name != "{if x.album}":
-                    if name != "{/if}":
-                        count_id = ids[a].strip("/song?id=")
-                        if not ('$' in count_id):
-                            song_url = f"{base_url}{count_id}.mp3"
-                            logs.系统日志(f'存储文件：{name}.mp3')
-                            music = requests.get(song_url).content
-                            with open(f'{name}.mp3', "wb") as file:
-                                file.write(music)
-                                file.close()
+    Fishconsole Fishsys 网易云音乐模块
+
+    ----
+
+    摸鱼神器，一次只能爬10首歌，这也是为什么歌单要list
+
+
+    :param 歌单链接: 每个歌单的链接就是数组当中的一个值
+    :return: 返回一首歌文件，就在你程序的目录下
+    """
+    a = 强制类型检测(歌单链接, "list")
+    if a:
+        if 官网存活性检测('https://link.hhtjim.com/163/'):
+            import requests
+            from lxml import html
+            etree = html.etree
+            urllist = 歌单链接
+            base_url = 'https://link.hhtjim.com/163/'
+            count = 0
+            for url in urllist:
+                count = count + 1
+                print(logs.颜色(logs.分割线(f"开始第{count}次爬取", "Spider"), 色选="红色"))
+                try:
+                    result = requests.get(url).text
+                except:
+                    logs.安全退出("Fishsys》网易云音乐》爬虫》非法内容")
+                dom = etree.HTML(result)
+                # //a[@contains内容(@href指定查找的内容,'song?'含有的)]/@href里面的链接文字
+                ids = dom.xpath('//a[contains(@href,"song?")]/@href')
+                names = dom.xpath('//a[contains(@href,"song?")]/text()')
+                print(ids)
+                a = -1
+                for name in names:
+                    a = a + 1
+                    if not ('$' in name):
+                        if name != "{if x.album}":
+                            if name != "{/if}":
+                                count_id = ids[a].strip("/song?id=")
+                                if not ('$' in count_id):
+                                    song_url = f"{base_url}{count_id}.mp3"
+                                    logs.系统日志(f'存储文件：{name}.mp3')
+                                    music = requests.get(song_url).content
+                                    try:
+                                        with open(f'{name}.mp3', "wb") as file:
+                                            file.write(music)
+                                            file.close()
+                                    except:
+                                        print(logs.安全退出("Fishsys》网易云音乐》文件写入》写入失败"))
+        else:
+            logs.安全退出("Fishsys》网易云音乐》官网存活性检测》官网连接失败")
+    else:
+        logs.安全退出("Fishsys》网易云音乐》强制类型检测》请输入list类型的数据")
 
 
 def 排名(数据源: list, 第几个: int):
-    b=强制类型检测(数据源,"list")
+    b = 强制类型检测(数据源, "list")
     if b:
-        1+1
+        第几个 = int(第几个)
+        第几个 = 第几个 - 1
+        a = 数据源
+        for i in range(len(a)):
+            for j in range(0, len(a) - 1):
+                if a[j] > a[j + 1]:
+                    a[j], a[j + 1] = a[j + 1], a[j]
+        return a[第几个]
     else:
-        print(logs.日志(f"Fishconsole{fcv.version()}》Fishsys》排名》强制类型检测》请指定list类型的数据源","红色"))
-    第几个=int(第几个)
-    第几个 = 第几个 - 1
-    a = 数据源
-    for i in range(len(a)):
-        for j in range(0, len(a) - 1):
-            if a[j] > a[j + 1]:
-                a[j], a[j + 1] = a[j + 1], a[j]
-    return a[第几个]
+        logs.安全退出("Fishsys》排名》强制类型检测》请指定list类型的数据源")
 
 
 def 文件存在性检测(文件名: str):
+    """
+
+    Fishconsole Fishsys 文件存在性检测模块
+
+    ----
+
+    :param 文件名:你需要检测的文件
+
+    :return: 布尔值
+    """
     import os
     if not os.path.exists(文件名):
         logs.系统日志("文件存在性检测》文件未被发现，将返回布尔类型的值False", filecheck)
@@ -576,15 +649,36 @@ def 文件存在性检测(文件名: str):
 
 
 def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
+    """
+
+    Fishconsole Fishsys 缓存模块
+
+    ----
+
+    就是存数据，方便程序在下一次运行的时候调用
+
+
+    :param 模式:1是存储，2是读取
+
+    :param 数据:你要存的数据
+
+    :param 文件名:指定的文件名（默认为Fishconsole.fcc）
+
+    :return:  文件或者dict类型的值
+    """
     模式 = str(模式)
     if 模式 == "1":
-        数据 = str(数据)
-        数据 = passwordsys(1, 数据, "")
-        with open(f'{文件名}', "w") as file:
-            file.write(数据)
-            logs.系统日志("缓存》写入文件完成", cache)
-            logs.系统日志(f"缓存》{文件名}", cache)
-            file.close()
+        a = 强制类型检测(数据, 'dict')
+        if a:
+            数据 = str(数据)
+            数据 = passwordsys(1, 数据, "")
+            with open(f'{文件名}', "w") as file:
+                file.write(数据)
+                logs.系统日志("缓存》写入文件完成", cache)
+                logs.系统日志(f"缓存》{文件名}", cache)
+                file.close()
+        else:
+            logs.安全退出("》请使用dict的数据", 数据)
     elif 模式 == "2":
         if 文件存在性检测(f"{文件名}"):
             with open(f'{文件名}', "r") as file:
@@ -606,6 +700,17 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc"):
 
 
 def 字符转unicode(模式, 原文: str):
+    """
+    Fishconsole 字符转unicode 模块
+
+    ----
+
+     顾名思义，就是这个（肝不动了。。）
+
+    :param 模式: 1是加密，2是解密
+    :param 原文: 原始文字
+    :return: 加工过后的str类型的文字
+    """
     模式 = str(模式)
     原文 = str(原文)
     if 模式 == "1":
@@ -630,6 +735,64 @@ def 字符转unicode(模式, 原文: str):
         logs.错误跟踪(["Fishconsole", "字符串转unicode", "模式"], "请选择正确的模式", {模式})
 
 
+def 官网存活性检测(官网地址: str):
+    """
+    Fishconsole Fishsys官网存活性检测
+
+    ----
+
+    - 就是判断官网能不能链接，可以用来检测联网，能联返回ture，不能返回False
+
+    :param 官网地址: 官网地址
+    :return: 布尔值
+    """
+    import requests
+    try:
+        requests.get(官网地址, timeout=2)
+    except:
+        return False
+    return True
+
+
+def 讯飞云控(fid):
+    """
+
+    - 我记忆中对云控最字面的理解就是云端控制，也就是从服务器中下载需要的数据
+
+    - 这时，就要白嫖服务器了，这里选择讯飞（感谢Coolapk@寒鸽的FusionApp让我在初一时第一次体验了更新弹窗的实现方式）
+
+    ----
+    FishConsole Fishsys 讯飞云控模块
+    ----
+    ----
+
+    :param fid: 讯飞语记fid（如何获得？使用检查，找到相关的json数据就可以拿走fid）
+
+
+    :return: 字典或列表
+    """
+    import json
+    import requests
+    if 官网存活性检测("https://iflynote.com/i/"):
+        fid = str(fid)
+        url = f"https://api.iflynote.com/notes/share/doc/shareFileDetail?fid={fid}"
+        header = {
+            'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.64 Mobile Safari/537.36 Edg/101.0.1210.47'}
+        res = requests.get(url, headers=header).text
+        try:
+            res = json.loads(res)["data"]["coop"]["ops"]
+            res = res[0]
+            res = res["insert"]
+            res = res.replace("\n", "")
+            res = eval(res)
+            logs.变量查看("res", res)
+        except:
+            logs.变量查看("res", res)
+            logs.安全退出("Fishsys》讯飞云控》类型转换器》出现意外，可能是解析模式错误或json文档版本过低或者你在云控乱敲")
+    else:
+        logs.安全退出("Fishsys》讯飞云控》网络链接失败")
+    return res
+
 
 # 你要删我也没办法，反正如果出了什么错过了重大更新你就自己乐呵去呗
 # 这个不是模块，我们将会在导入该模块的时候顺序执行此处
@@ -700,4 +863,3 @@ if sys:
 else:
     # 这是关闭了更新时执行的操作
     logs.日志("fcv_debug已取消强制更新系统的执行", "绿色")
-
