@@ -1,4 +1,10 @@
 # coding utf-8
+"""
+这是Fishconsole Project的帮助模块，本地帮助文档的启动和检查更新都由它执行
+
+----
+
+"""
 import requests
 from lxml import html
 
@@ -34,6 +40,20 @@ def isConnected():
 
 
 def 帮助():
+    """
+    FishConsole helps 主程序
+
+    ----
+
+    - 查看内置帮助文档，检测更新都是它在干
+
+    - 如何启动，直接调用就可以了
+
+    :return: <启动主程序>
+    """
+
+
+
     sys = fcv.f_debug()
     sys = sys["updata"]
     print(logs.颜色(
@@ -360,12 +380,31 @@ def 帮助():
                         "文件存在性检测模块",
                         "缓存模块",
                         "文本转Unicode模块",
-                        "强制类型检测"
+                        "强制类型检测",
+                        "讯飞云控",
+                        "官网存活性检测",
                     ])
                     logs.系统日志(f"用户请求启动{res}")
                     if res == None:
                         logs.安全退出("用户取消了操作")
                     for a in res:
+                        if a == "官网存活性检测":
+                            window.弹窗(
+                                "其实就是一爬虫，看官网存不存在，也可以用来检测联网没有\n"
+                                "-----------------------------\n\n"
+                                "语法就是\n"
+                                "Fishsys.官网存活性检测(官网地址)\n\n"
+                                "有返回Ture，没有返回False"
+                                , "官网存活性检测", "ok")
+                        if a == "讯飞云控":
+                            window.弹窗(
+                                "我记忆中对云控最字面的理解就是云端控制，也就是从服务器中下载需要的数据\n\n"
+                                "这时，就要白嫖服务器了，这里选择讯飞（感谢Coolapk@寒鸽的FusionApp让我在初一时第一次体验了更新弹窗的实现方式）\n"
+                                "-----------------------------\n\n"
+                                "语法就是\n"
+                                "Fishsys.讯飞云控(fid)\n\n"
+                                "讯飞语记fid（如何获得？使用检查，找到相关的json数据就可以拿走fid）"
+                                , "讯飞云控", "ok")
                         if a == "密码模块":
                             window.弹窗(
                                 "这个加密其实特别简单，就是把一个字换成另一个字让你看不懂就行了，嗯，他的值是返回过来的\n"
@@ -428,3 +467,4 @@ def 帮助():
                                 "如果传入的变量类型符合预期的变量类型，就返回Ture，否则返回False。\n\n"
                                 "其实也就那样了\n"
                                 , "强制类型检测", "ok")
+
