@@ -1,7 +1,18 @@
+"""
+这是Fishconsole Project的matplilib中文辅助模块
+
+----
+
+为什么这个没有简洁？
+
+我靠，我写的参数还不够明确啊？
+
+主要是这个太大了，我没心情写
+
+"""
+
 import matplotlib.pyplot as plt
-from Fishconsole import fcv
 from Fishconsole import Fishsys
-from Fishconsole import helps
 from Fishconsole import logs
 
 logs.系统日志("用户调用了huitu模块")
@@ -9,6 +20,17 @@ logs.系统日志("用户调用了huitu模块")
 def 单线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源: list, 网格线=False, x轴名="x", y轴名="y", 线的样式="-", 线的颜色="b", 线的宽度=2, 画布长=6, 画布宽=6,
           标题=None,
           绘图标记=None, 网格线样式='-', 网格线方向="both", 网格线RGB="#000", 网格线宽度=0.5):
+    a=Fishsys.强制类型检测(x轴数据源,"list")
+    b=Fishsys.强制类型检测(y轴数据源,"list")
+    if a:
+        1+1;
+    else:
+        logs.安全退出("huitu》强制类型检测》单线折现图》请对x轴数据源使用list类型的数据")
+
+    if b:
+        1+1;
+    else:
+        logs.安全退出("huitu》强制类型检测》单线折现图》请对y轴数据源使用list类型的数据")
     # 修复可能出现的负数
     plt.rcParams['axes.unicode_minus'] = False
     # 画布长宽
@@ -37,6 +59,26 @@ def 单线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源:
 def 双线折线图(x轴范围, x轴数据源: list, y轴范围, y轴数据源: list, xa轴范围, xa轴数据源: list, ya轴范围, ya轴数据源: list, 网格线=False, ya轴名="ya",
           xa轴名="xa", y轴名="y", x轴名="x",
           线的样式="-", 线的宽度=2, 画布长=6, 画布宽=6, 标题=None, 绘图标记=None, 网格线方向="both", 网格线样式='-', 网格线RGB="#000", 网格线宽度=0.5):
+    a=Fishsys.强制类型检测(x轴数据源,"list")
+    b=Fishsys.强制类型检测(y轴数据源, "list")
+    c=Fishsys.强制类型检测(xa轴数据源, "list")
+    d=Fishsys.强制类型检测(ya轴数据源, "list")
+    if a:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》双线折现图》请对x轴数据源使用list类型的数据")
+    if b:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》双线折现图》请对y轴数据源使用list类型的数据")
+    if c:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》双线折现图》请对xa轴数据源使用list类型的数据")
+    if d:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》双线折现图》请对ya轴数据源使用list类型的数据")
     # 修复可能出现的负数
     plt.rcParams['axes.unicode_minus'] = False
     # 画布长宽
@@ -82,6 +124,46 @@ def 子图(模式, 总标题=None, 子图a标题=None, 子图b标题=None, 子
        绘图标记: str = None,
        网格线方向="both", 网格线样式='-', 网格线RGB="#000", 网格线宽度=0.5, 网格线=False, x轴名="x", y轴名="y", xa轴名="xa", ya轴名="ya",
        xb轴名="xb", yb轴名="yb", xc轴名="xc", yc轴名="yc"):
+    a=Fishsys.强制类型检测(x轴数据源, "list")
+    b=Fishsys.强制类型检测(y轴数据源, "list")
+    c=Fishsys.强制类型检测(xa轴数据源, "list")
+    d=Fishsys.强制类型检测(ya轴数据源, "list")
+    e=Fishsys.强制类型检测(xb轴数据源, "list")
+    f=Fishsys.强制类型检测(yb轴数据源, "list")
+    g=Fishsys.强制类型检测(xc轴数据源, "list")
+    h=Fishsys.强制类型检测(xc轴数据源, "list")
+    if a:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对x轴数据源使用list类型的数据")
+    if b:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对y轴数据源使用list类型的数据")
+    if c:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对xa轴数据源使用list类型的数据")
+    if d:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对ya轴数据源使用list类型的数据")
+    if e:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对xb轴数据源使用list类型的数据")
+    if f:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对yc轴数据源使用list类型的数据")
+    if g:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对xc轴数据源使用list类型的数据")
+    if h:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》子图》请对yc轴数据源使用list类型的数据")
     模式 = str(模式)
     if 模式 == "2":
         # 子图1
@@ -100,7 +182,6 @@ def 子图(模式, 总标题=None, 子图a标题=None, 子图b标题=None, 子
         plt.rcParams['font.sans-serif'] = ['SimHei']
         if 网格线:
             plt.grid(axis=f"{网格线方向}", color=网格线RGB, linewidth=网格线宽度, linestyle=网格线样式, marker=f'{绘图标记}')
-
         # 子图2
         x = xa轴数据源
         y = ya轴数据源
@@ -117,7 +198,6 @@ def 子图(模式, 总标题=None, 子图a标题=None, 子图b标题=None, 子
         plt.rcParams['font.sans-serif'] = ['SimHei']
         if 网格线:
             plt.grid(axis=f"{网格线方向}", color=网格线RGB, linewidth=网格线宽度, linestyle=网格线样式, marker=f'{绘图标记}')
-
         plt.suptitle(f"{总标题}")
         plt.show()
 
@@ -251,6 +331,21 @@ def 子图(模式, 总标题=None, 子图a标题=None, 子图b标题=None, 子
 def 柱形图(x轴名: list, y轴数据: list, 背景: list = None, 模式="竖", 宽度=0.5, 高度=0.1, 标题=None, 网格线=False, 网格线方向="both", 网格线样式='-',
         网格线RGB="#000",
         网格线宽度=0.5):
+    a=Fishsys.强制类型检测(x轴名, "list")
+    b=Fishsys.强制类型检测(y轴数据, "list")
+    c=Fishsys.强制类型检测(背景, "list")
+    if a:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》柱形图》请对x轴名使用list类型的数据")
+    if b:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》柱形图》请对y轴数据使用list类型的数据")
+    if c:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》柱形图》请对背景使用list类型的数据")
     if 模式 == "竖":
         plt.bar(x轴名, y轴数据, color=背景, width=宽度)
     else:
@@ -268,6 +363,21 @@ def 柱形图(x轴名: list, y轴数据: list, 背景: list = None, 模式="竖"
 def 饼图(数据: list, 数据标签: list = None, 数据颜色: list = None, 总标题=None, 百分比=False):
     plt.pie(数据, labels=数据标签, colors=数据颜色)
     plt.title(总标题)  # 设置标题
+    a=Fishsys.强制类型检测(数据, "list")
+    b=Fishsys.强制类型检测(数据标签, "list")
+    c=Fishsys.强制类型检测(数据颜色, "list")
+    if a:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》饼图》请对数据使用list类型的数据")
+    if b:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》饼图》请对数据标签使用list类型的数据")
+    if c:
+        1+1
+    else:
+        logs.安全退出("huitu》强制类型检测》饼图》请对数据颜色使用list类型的数据")
     if 百分比:
         plt.pie(数据, labels=数据标签, colors=数据颜色, autopct='%.2f%%')
     # 修复可能出现的负数
