@@ -1,4 +1,12 @@
 # ecoding=utf-8
+
+"""
+这是Fishconsole Project的easygui中文模块，我也没法说什么
+
+----
+
+"""
+
 import easygui
 # 虽然没什么用，但是里面的强制更新系统可以很好的牵制调用
 from Fishconsole import Fishsys
